Struct KeyboardEnhancementFlags
pub struct KeyboardEnhancementFlags(/* private fields */);term only.Expand description
Represents special flags that tell compatible terminals to add extra information to keyboard events.
See https://sw.kovidgoyal.net/kitty/keyboard-protocol/#progressive-enhancement for more information.
Alternate keys and Unicode codepoints are not yet supported by crossterm.
Implementations
impl KeyboardEnhancementFlags
impl KeyboardEnhancementFlags
pub const DISAMBIGUATE_ESCAPE_CODES: KeyboardEnhancementFlags
pub const DISAMBIGUATE_ESCAPE_CODES: KeyboardEnhancementFlags
Represent Escape and modified keys using CSI-u sequences, so they can be unambiguously read.
pub const REPORT_EVENT_TYPES: KeyboardEnhancementFlags
pub const REPORT_EVENT_TYPES: KeyboardEnhancementFlags
Add extra events with [KeyEvent.kind] set to KeyEventKind::Repeat or
KeyEventKind::Release when keys are autorepeated or released.
pub const REPORT_ALTERNATE_KEYS: KeyboardEnhancementFlags
pub const REPORT_ALTERNATE_KEYS: KeyboardEnhancementFlags
Send alternate keycodes
in addition to the base keycode. The alternate keycode overrides the base keycode in
resulting KeyEvents.
pub const REPORT_ALL_KEYS_AS_ESCAPE_CODES: KeyboardEnhancementFlags
pub const REPORT_ALL_KEYS_AS_ESCAPE_CODES: KeyboardEnhancementFlags
Represent all keyboard events as CSI-u sequences. This is required to get repeat/release events for plain-text keys.
impl KeyboardEnhancementFlags
impl KeyboardEnhancementFlags
pub const fn empty() -> KeyboardEnhancementFlags
pub const fn empty() -> KeyboardEnhancementFlags
Get a flags value with all bits unset.
pub const fn all() -> KeyboardEnhancementFlags
pub const fn all() -> KeyboardEnhancementFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u8) -> Option<KeyboardEnhancementFlags>
pub const fn from_bits(bits: u8) -> Option<KeyboardEnhancementFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u8) -> KeyboardEnhancementFlags
pub const fn from_bits_truncate(bits: u8) -> KeyboardEnhancementFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u8) -> KeyboardEnhancementFlags
pub const fn from_bits_retain(bits: u8) -> KeyboardEnhancementFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<KeyboardEnhancementFlags>
pub fn from_name(name: &str) -> Option<KeyboardEnhancementFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: KeyboardEnhancementFlags) -> bool
pub const fn intersects(&self, other: KeyboardEnhancementFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: KeyboardEnhancementFlags) -> bool
pub const fn contains(&self, other: KeyboardEnhancementFlags) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: KeyboardEnhancementFlags)
pub fn insert(&mut self, other: KeyboardEnhancementFlags)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: KeyboardEnhancementFlags)
pub fn remove(&mut self, other: KeyboardEnhancementFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: KeyboardEnhancementFlags)
pub fn toggle(&mut self, other: KeyboardEnhancementFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: KeyboardEnhancementFlags, value: bool)
pub fn set(&mut self, other: KeyboardEnhancementFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(
self,
other: KeyboardEnhancementFlags,
) -> KeyboardEnhancementFlags
pub const fn intersection( self, other: KeyboardEnhancementFlags, ) -> KeyboardEnhancementFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(
self,
other: KeyboardEnhancementFlags,
) -> KeyboardEnhancementFlags
pub const fn union( self, other: KeyboardEnhancementFlags, ) -> KeyboardEnhancementFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(
self,
other: KeyboardEnhancementFlags,
) -> KeyboardEnhancementFlags
pub const fn difference( self, other: KeyboardEnhancementFlags, ) -> KeyboardEnhancementFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: KeyboardEnhancementFlags,
) -> KeyboardEnhancementFlags
pub const fn symmetric_difference( self, other: KeyboardEnhancementFlags, ) -> KeyboardEnhancementFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> KeyboardEnhancementFlags
pub const fn complement(self) -> KeyboardEnhancementFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl KeyboardEnhancementFlags
impl KeyboardEnhancementFlags
pub const fn iter(&self) -> Iter<KeyboardEnhancementFlags> ⓘ
pub const fn iter(&self) -> Iter<KeyboardEnhancementFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<KeyboardEnhancementFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<KeyboardEnhancementFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.