PopKeyboardEnhancementFlags

Struct PopKeyboardEnhancementFlags 

pub struct PopKeyboardEnhancementFlags;
Available on crate feature term only.
A command that disables extra kinds of keyboard events.

Specifically, it pops one level of keyboard enhancement flags.

See PushKeyboardEnhancementFlags and https://sw.kovidgoyal.net/kitty/keyboard-protocol/ for more information.