Struct PushKeyboardEnhancementFlags
pub struct PushKeyboardEnhancementFlags(pub KeyboardEnhancementFlags);Available on crate feature
term only.Expand description
A command that enables the kitty keyboard protocol, which adds extra information to keyboard events and removes ambiguity for modifier keys.
It should be paired with PopKeyboardEnhancementFlags at the end of execution.
Example usage:
use std::io::{Write, stdout};
use crossterm::execute;
use crossterm::event::{
KeyboardEnhancementFlags,
PushKeyboardEnhancementFlags,
PopKeyboardEnhancementFlags
};
let mut stdout = stdout();
execute!(
stdout,
PushKeyboardEnhancementFlags(
KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES
)
);
// ...
execute!(stdout, PopKeyboardEnhancementFlags);Note that, currently, only the following support this protocol:
Tuple Fields
0: KeyboardEnhancementFlagsTrait Implementations
impl Clone for PushKeyboardEnhancementFlags
impl Clone for PushKeyboardEnhancementFlags
fn clone(&self) -> PushKeyboardEnhancementFlags
fn clone(&self) -> PushKeyboardEnhancementFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Command for PushKeyboardEnhancementFlags
impl Command for PushKeyboardEnhancementFlags
impl Copy for PushKeyboardEnhancementFlags
impl Debug for PushKeyboardEnhancementFlags
impl Debug for PushKeyboardEnhancementFlags
impl Eq for PushKeyboardEnhancementFlags
impl PartialEq for PushKeyboardEnhancementFlags
impl PartialEq for PushKeyboardEnhancementFlags
impl StructuralPartialEq for PushKeyboardEnhancementFlags